summaryrefslogtreecommitdiff
path: root/core/opiealarm
authorsandman <sandman>2002-12-10 22:21:58 (UTC)
committer sandman <sandman>2002-12-10 22:21:58 (UTC)
commit887fb36c5344574f04d19c7442f3db899920e04d (patch) (side-by-side diff)
tree3a1ccbdb5489bf628979a2b712a779ae009383dc /core/opiealarm
parent2173e57fcbd5d460fceb34a111845389dca56506 (diff)
downloadopie-887fb36c5344574f04d19c7442f3db899920e04d.zip
opie-887fb36c5344574f04d19c7442f3db899920e04d.tar.gz
opie-887fb36c5344574f04d19c7442f3db899920e04d.tar.bz2
/etc/resumeat is now in /var/run/resumeat
Diffstat (limited to 'core/opiealarm') (more/less context) (ignore whitespace changes)
-rw-r--r--core/opiealarm/opiealarm.c15
1 files changed, 8 insertions, 7 deletions
diff --git a/core/opiealarm/opiealarm.c b/core/opiealarm/opiealarm.c
index 5ea24b7..072dca7 100644
--- a/core/opiealarm/opiealarm.c
+++ b/core/opiealarm/opiealarm.c
@@ -26,6 +26,7 @@
#define PIDFILE "/var/run/opiealarm.pid"
+#define TIMEFILE "/var/run/resumeat"
#define APMFILE "/proc/apm"
int resume ( int resuspend );
@@ -245,23 +246,23 @@ int suspend ( int fix_rtc )
// if the difference between system and hardware time is more than 3 seconds,
// we have to set the RTC (hwclock --systohc), or alarms won't work reliably.
- if ( ioctl ( fd, RTC_SET_TIME, &set ) < 0 )
+ if ( ioctl ( fd, RTC_SET_TIME, &set ) < 0 )
break; // ( 1, "ioctl RTC_SET_TIME" );
}
- // read the wakeup time from /etc/resumeat
- if (!( fp = fopen ( "/etc/resumeat", "r" )))
- break; // ( 1, "/etc/resumeat" );
+ // read the wakeup time from TIMEFILE
+ if (!( fp = fopen ( TIMEFILE, "r" )))
+ break; // ( 1, TIMEFILE );
if ( !fgets ( buf, sizeof( buf ) - 1, fp ))
- break; // ( 1, "/etc/resumeat" );
+ break; // ( 1, TIMEFILE );
fclose ( fp );
alrt = atoi ( buf ); // get the alarm time
if ( alrt == 0 )
- break; // ( 0, "/etc/resumeat contains an invalid time description" );
+ break; // ( 0, TIMEFILE " contains an invalid time description" );
alrt -= 5; // wake up 5 sec before the specified time
alr = *gmtime ( &alrt );
@@ -290,7 +291,7 @@ int suspend ( int fix_rtc )
return 0;
- } while ( 0 )
+ } while ( 0 );
if ( fp != NULL )
fclose ( fp );